Class: Google::Apis::BigqueryconnectionV1::ConnectorConfiguration
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryconnectionV1::ConnectorConfiguration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigqueryconnection_v1/classes.rb,
lib/google/apis/bigqueryconnection_v1/representations.rb,
lib/google/apis/bigqueryconnection_v1/representations.rb
Overview
Represents concrete parameter values for Connector Configuration.
Instance Attribute Summary collapse
-
#asset ⇒ Google::Apis::BigqueryconnectionV1::ConnectorConfigurationAsset
Data Asset - a resource within instance of the system, reachable under specified endpoint.
-
#authentication ⇒ Google::Apis::BigqueryconnectionV1::ConnectorConfigurationAuthentication
Client authentication.
-
#connector_id ⇒ String
Required.
-
#endpoint ⇒ Google::Apis::BigqueryconnectionV1::ConnectorConfigurationEndpoint
Remote endpoint specification.
-
#network ⇒ Google::Apis::BigqueryconnectionV1::ConnectorConfigurationNetwork
Network related configuration.
-
#parameters ⇒ Hash<String,Google::Apis::BigqueryconnectionV1::ConnectorConfigurationParameterValue>
Optional.
-
#tls ⇒ Google::Apis::BigqueryconnectionV1::ConnectorConfigurationTls
TLS configuration options.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConnectorConfiguration
constructor
A new instance of ConnectorConfiguration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConnectorConfiguration
Returns a new instance of ConnectorConfiguration.
620 621 622 |
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 620 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset ⇒ Google::Apis::BigqueryconnectionV1::ConnectorConfigurationAsset
Data Asset - a resource within instance of the system, reachable under
specified endpoint. For example a database name in a SQL DB.
Corresponds to the JSON property asset
581 582 583 |
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 581 def asset @asset end |
#authentication ⇒ Google::Apis::BigqueryconnectionV1::ConnectorConfigurationAuthentication
Client authentication.
Corresponds to the JSON property authentication
586 587 588 |
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 586 def authentication @authentication end |
#connector_id ⇒ String
Required. Immutable. The ID of the Connector these parameters are configured
for.
Corresponds to the JSON property connectorId
592 593 594 |
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 592 def connector_id @connector_id end |
#endpoint ⇒ Google::Apis::BigqueryconnectionV1::ConnectorConfigurationEndpoint
Remote endpoint specification.
Corresponds to the JSON property endpoint
597 598 599 |
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 597 def endpoint @endpoint end |
#network ⇒ Google::Apis::BigqueryconnectionV1::ConnectorConfigurationNetwork
Network related configuration.
Corresponds to the JSON property network
602 603 604 |
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 602 def network @network end |
#parameters ⇒ Hash<String,Google::Apis::BigqueryconnectionV1::ConnectorConfigurationParameterValue>
Optional. A map of name-value pairs for connector-specific parameters. These
extra configuration parameters aren't standardized in the configuration
sections. To update a single parameter value, call ConnectionService.
UpdateConnection with update_mask set to configuration.parameters.
parameter_id. If parameter_id doesn't fit the [a-zA-Z0-9_]+ pattern,
parameter_id should be escaped with backticks—for example, configuration.
parameters.`parameter id`.
Corresponds to the JSON property parameters
613 614 615 |
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 613 def parameters @parameters end |
#tls ⇒ Google::Apis::BigqueryconnectionV1::ConnectorConfigurationTls
TLS configuration options.
Corresponds to the JSON property tls
618 619 620 |
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 618 def tls @tls end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
625 626 627 628 629 630 631 632 633 |
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 625 def update!(**args) @asset = args[:asset] if args.key?(:asset) @authentication = args[:authentication] if args.key?(:authentication) @connector_id = args[:connector_id] if args.key?(:connector_id) @endpoint = args[:endpoint] if args.key?(:endpoint) @network = args[:network] if args.key?(:network) @parameters = args[:parameters] if args.key?(:parameters) @tls = args[:tls] if args.key?(:tls) end |