Class: Google::Apis::BigqueryconnectionV1::SparkProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigqueryconnection_v1/classes.rb,
lib/google/apis/bigqueryconnection_v1/representations.rb,
lib/google/apis/bigqueryconnection_v1/representations.rb

Overview

Container for connection properties to execute stored procedures for Apache Spark.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SparkProperties

Returns a new instance of SparkProperties.



1312
1313
1314
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 1312

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metastore_service_configGoogle::Apis::BigqueryconnectionV1::MetastoreServiceConfig

Configuration of the Dataproc Metastore Service. Corresponds to the JSON property metastoreServiceConfig



1294
1295
1296
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 1294

def metastore_service_config
  @metastore_service_config
end

#service_account_idString

Output only. The account ID of the service created for the purpose of this connection. The service account does not have any permissions associated with it when it is created. After creation, customers delegate permissions to the service account. When the connection is used in the context of a stored procedure for Apache Spark in BigQuery, the service account is used to connect to the desired resources in Google Cloud. The account ID is in the form of: bqcx--@gcp-sa-bigquery-consp.iam.gserviceaccount.com Corresponds to the JSON property serviceAccountId

Returns:

  • (String)


1305
1306
1307
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 1305

def 
  @service_account_id
end

#spark_history_server_configGoogle::Apis::BigqueryconnectionV1::SparkHistoryServerConfig

Configuration of the Spark History Server. Corresponds to the JSON property sparkHistoryServerConfig



1310
1311
1312
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 1310

def spark_history_server_config
  @spark_history_server_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1317
1318
1319
1320
1321
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 1317

def update!(**args)
  @metastore_service_config = args[:metastore_service_config] if args.key?(:metastore_service_config)
  @service_account_id = args[:service_account_id] if args.key?(:service_account_id)
  @spark_history_server_config = args[:spark_history_server_config] if args.key?(:spark_history_server_config)
end