Class: Google::Apis::BigqueryconnectionV1::ConnectorConfigurationAuthentication
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryconnectionV1::ConnectorConfigurationAuthentication
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigqueryconnection_v1/classes.rb,
lib/google/apis/bigqueryconnection_v1/representations.rb,
lib/google/apis/bigqueryconnection_v1/representations.rb
Overview
Client authentication.
Instance Attribute Summary collapse
-
#parameters ⇒ Hash<String,Google::Apis::BigqueryconnectionV1::ConnectorConfigurationParameterValue>
Optional.
-
#service_account ⇒ String
Output only.
-
#username_password ⇒ Google::Apis::BigqueryconnectionV1::ConnectorConfigurationUsernamePassword
Username and Password authentication.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConnectorConfigurationAuthentication
constructor
A new instance of ConnectorConfigurationAuthentication.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConnectorConfigurationAuthentication
Returns a new instance of ConnectorConfigurationAuthentication.
685 686 687 |
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 685 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parameters ⇒ Hash<String,Google::Apis::BigqueryconnectionV1::ConnectorConfigurationParameterValue>
Optional. A map of name-value pairs for authentication-specific parameters.
Extra configuration parameters, that are not standardized in authentication.
To update a single parameter value call ConnectionService.UpdateConnection
with update_mask set to configuration.authentication.parameters.
parameter_id. If parameter id does not fit [a-zA-Z0-9_]+ pattern, it should
be escaped with backticks - for example configuration.authentication.
parameters.`parameter id`.
Corresponds to the JSON property parameters
670 671 672 |
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 670 def parameters @parameters end |
#service_account ⇒ String
Output only. Google-managed service account associated with this connection, e.
g., service-project_number@gcp-sa-bigqueryconnection.iam.gserviceaccount.
com. BigQuery jobs using this connection will act as service_account
identity while connecting to the datasource.
Corresponds to the JSON property serviceAccount
678 679 680 |
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 678 def service_account @service_account end |
#username_password ⇒ Google::Apis::BigqueryconnectionV1::ConnectorConfigurationUsernamePassword
Username and Password authentication.
Corresponds to the JSON property usernamePassword
683 684 685 |
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 683 def username_password @username_password end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
690 691 692 693 694 |
# File 'lib/google/apis/bigqueryconnection_v1/classes.rb', line 690 def update!(**args) @parameters = args[:parameters] if args.key?(:parameters) @service_account = args[:service_account] if args.key?(:service_account) @username_password = args[:username_password] if args.key?(:username_password) end |